==> nextcloud-app-mail-0.6.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uk.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Повідомлення",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n нове повідомлення у {folderName}\nвід {from}","%n нових повідомлень у {folderName}\nвід {from}","%n нових повідомлень у {folderName}\nвід {from}"],
    "Error while loading the accounts." : "Помилка завантаження облікового запису",
    "Error while loading the selected account." : "Помилка завантаження обраного облікового запису.",
    "Error while loading messages." : "Помилка завантаження повідомлень.",
    "Error while loading the selected message." : "Помилка завантаження обраного повідомлення.",
    "Forwarded message" : "Пререадресоване повідомлення",
    "Choose a folder to store the attachment in" : "Оберіть теку для зберігання вкладень",
    "Attachments saved to Files." : "Вкладення збережені до Файлів.",
    "Attachment saved to Files." : "Вкладення збережено до Файлів.",
    "Error while saving attachments to Files." : "Помилка збереження вкладень до Файлів.",
    "Error while saving attachment to Files." : "Помилка збереження вкладення до Файлів.",
    "Invalid folder" : "Невірна тека",
    "Unknown error" : "Невідома помилка",
    "Error while creating an account: " : "Помилка при створенні облікового запису:",
    "Show all folders" : "Переглянути всі теки",
    "Collapse folders" : "Згорнути теки",
    "Error while deleting account." : "Помилка при видалені облікового запису.",
    "Choose a file to add as attachment" : "Обрати файл для вкладення",
    "Reply" : "Відповісти",
    "Send" : "Надіслати",
    "Sending …" : "Надсилання...",
    "Message sent!" : "Повідомлення відправлено!",
    "Server error" : "Помилка серверу",
    "Opening HTML drafts is not supported yet." : "Відкриті HTML чернетки поки не підтримуються.",
    "Draft saved!" : "Чернетку збережено!",
    "you" : "ви",
    "Send message to {email}" : "Надіслати повідомлення {email}",
    "Error while deleting message." : "Помилка видалення повідомлення.",
    "Connecting" : "Підключення",
    "Connect" : "З'єднати",
    "Inbox" : "Вхідні",
    "Sent" : "Надіслані",
    "Drafts" : "Чорновики",
    "Archive" : "Архів",
    "Trash" : "Смітник",
    "Junk" : "Спам",
    "All" : "Всі",
    "Favorites" : "Улюблені",
    "Creating account failed: " : "Помилка створення облікового запису:",
    "Auto detect failed. Please use manual mode." : "Авто-виявлення не спрацювало. Будь ласка, скористайтесь ручний режимом.",
    "Delete permanently" : "Видалити назавжди",
    "& others" : "та інші",
    "All inboxes" : "Всі вхідні",
    "Error loading message" : "Помилка завантаження повідомлення.",
    "Continue to %s" : "Подовження за %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uk.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Повідомлення",
    "Error while loading the accounts." : "Помилка завантаження облікового запису",
    "Error while loading the selected account." : "Помилка завантаження обраного облікового запису.",
    "Error while deleting message." : "Помилка видалення повідомлення.",
    "Forwarded message" : "Пререадресоване повідомлення",
    "Choose a folder to store the attachment in" : "Оберіть теку для зберігання вкладень",
    "Attachments saved to Files." : "Вкладення збережені до Файлів.",
    "Attachment saved to Files." : "Вкладення збережено до Файлів.",
    "Error while saving attachments to Files." : "Помилка збереження вкладень до Файлів.",
    "Error while saving attachment to Files." : "Помилка збереження вкладення до Файлів.",
    "Invalid folder" : "Невірна тека",
    "Unknown error" : "Невідома помилка",
    "All inboxes" : "Всі вхідні",
    "you" : "ви",
    "Send message to {email}" : "Надіслати повідомлення {email}",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Show all folders" : "Переглянути всі теки",
    "Collapse folders" : "Згорнути теки",
    "Error while deleting account." : "Помилка при видалені облікового запису.",
    "Choose a file to add as attachment" : "Обрати файл для вкладення",
    "Reply" : "Відповісти",
    "Send" : "Надіслати",
    "Sending …" : "Надсилання...",
    "Message sent!" : "Повідомлення відправлено!",
    "Server error" : "Помилка серверу",
    "Opening HTML drafts is not supported yet." : "Відкриті HTML чернетки поки не підтримуються.",
    "& others" : "та інші",
    "Error while loading messages." : "Помилка завантаження повідомлень.",
    "Inbox" : "Вхідні",
    "Sent" : "Надіслані",
    "Drafts" : "Чорновики",
    "Archive" : "Архів",
    "Trash" : "Смітник",
    "Junk" : "Спам",
    "All" : "Всі",
    "Favorites" : "Улюблені",
    "Auto detect failed. Please use manual mode." : "Авто-виявлення не спрацювало. Будь ласка, скористайтесь ручний режимом.",
    "Creating account failed: " : "Помилка створення облікового запису:",
    "Delete permanently" : "Видалити назавжди",
    "Error loading message" : "Помилка завантаження повідомлення.",
    "Continue to %s" : "Подовження за %s",
    "Connect" : "З'єднати"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
